==> omp-3.2.1-5.tar.gz: omp-3.2.1-5/docs/manual/en/users-and-roles.md <==
# Users and Roles

1. Introduction
2. [Users](users-and-roles#users-users)
3. [Roles](users-and-roles#users-roles)
4. [Site Access](users-and-roles#users-site-access)

Manager your press's users, assign them to roles and create or edit existing roles.

## <a name="users"></a> Users

Press Managers and Administrators can view a list of all users in the press. You can add users, disable a user, send them email, edit their profile or delete them completely.

The easiest way to find a user is to use the search button, which will allow you to search by name or role.

*To find a list of all authors, use the Search feature, leave the search field empty and select Author from the dropdown menu. Then click the Search button.*

## <a name="roles"></a> Roles

User roles govern who can access what in the editorial worfklow.

A flexible user role system is provided so that you can tailor the roles to your needs. On the Roles tab, you'll see a list of default roles created by the system.

There are many roles and most presses won't need all of them. Feel free to delete roles you won't use in your workflow.

You can edit or remove existing roles, or add new roles. All roles are given one of a few permission levels which allow them to perform various actions in the system:

- *Authors* can make new submissions.
- *Reviewers* appear when you're assigning reviews in the [Editorial Workflow](editorial-workflow) and have access to that stage when they're assigned.
- *Readers*, like all other user types, can access the reader-facing website. All users have this capability.
- *Press Managers* have access to the entire [Editorial Workflow](editorial-workflow), as well as most of the settings.
- *Series Editors* and *Press Assistants* can access only those parts of the [Editorial Workflow](editorial-workflow) assigned to their role (see below).

In addition to the permission levels, you can restrict some roles to particular stages of the [Editorial Workflow](editorial-workflow). This is useful for professional assistants such as copyeditors or layout managers who may assist during one or two stages of the workflow.

## <a name="site-access"></a> Site Access Options

Under the Site Access tab, you can turn off public user registration, or even limit access to the reader-facing site to registered users.

==> omp-3.3.0-18.tar.gz: omp-3.3.0-18/docs/manual/en/users-and-roles.md <==
# Users and Roles

1. [Users](users-and-roles#users)
2. [Roles](users-and-roles#roles)
3. [Notify](users-and-roles#notify)
4. [Site Access](users-and-roles#site-access)

Manager your press's users, assign them to roles and create or edit existing roles.

## <a name="users"></a> Users

Press Managers and Administrators can view a list of all users in the press. You can add users, disable a user, send them email, edit their profile or delete them completely.

The easiest way to find a user is to use the search button, which will allow you to search by name or role.

*To find a list of all authors, use the Search feature, leave the search field empty and select Author from the dropdown menu. Then click the Search button.*

## <a name="roles"></a> Roles

User roles govern who can access what in the editorial worfklow.

A flexible user role system is provided so that you can tailor the roles to your needs. On the Roles tab, you'll see a list of default roles created by the system.

There are many roles and most presses won't need all of them. Feel free to delete roles you won't use in your workflow.

You can edit or remove existing roles, or add new roles. All roles are given one of a few permission levels which allow them to perform various actions in the system:

- *Authors* can make new submissions.
- *Reviewers* appear when you're assigning reviews in the [Editorial Workflow](editorial-workflow) and have access to that stage when they're assigned.
- *Readers*, like all other user types, can access the reader-facing website. All users have this capability.
- *Press Managers* have access to the entire [Editorial Workflow](editorial-workflow), as well as most of the settings.
- *Series Editors* and *Press Assistants* can access only those parts of the [Editorial Workflow](editorial-workflow) assigned to their role (see below).

In addition to the permission levels, you can restrict some roles to particular stages of the [Editorial Workflow](editorial-workflow). This is useful for professional assistants such as copyeditors or layout managers who may assist during one or two stages of the workflow.

## <a name="notify"></a> Notify

If an Administrator has enabled the bulk emails feature, you will see a Notify tab. You can use this tab to email all users in a role.

## <a name="site-access"></a> Site Access Options

Under the Site Access tab, you can turn off public user registration, or even limit access to the reader-facing site to registered users.
